# Generated by Django 3.2.5 on 2022-07-14 10:32

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Callbacks',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('bank_id', models.IntegerField()),
                ('type_code', models.IntegerField()),
                ('reference', models.CharField(max_length=100)),
                ('callback', models.TextField()),
                ('request', models.JSONField(default=dict)),
                ('response', models.JSONField(default=dict)),
                ('request_time', models.DateTimeField(default=django.utils.timezone.now)),
                ('response_time', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
    ]
