# Generated by Django 3.2.5 on 2022-11-09 08:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0007_responselogs'),
    ]

    operations = [
        migrations.AddField(
            model_name='responselogs',
            name='ip',
            field=models.CharField(default=None, max_length=50, null=True),
        ),
    ]
